<?php
/*
  Plugin Name: Law For Websites
  Plugin URI: http://lawforwebsites.info
  Description: Adds privacy policy and terms of use to your website
  Version: 2.2
  Author: Tony
  Author URI: http://meoverhere.it
  Licence: GPLv2

  Copyright 2012 Jifkins IP, Tony Jifkins  (email : tony@jifkins.us)

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

  http://www.gnu.org/licenses/gpl.txt
*/

/** VERSION HISTORY
  Ver   Date        Author      Change
  1.1   28/09/2012  Tony        Add option to include/exclude autoresponder section.
  1.1   28/09/2012  Tony        fix spelling mistake in autoresponder section and make
                                it general rather than fixed for aweber.
  1.1   28/09/2012  Tony        reformat admin page.
  1.1   28/09/2012  Tony        Add installation and setup guide.
  1.2   07/11/2012  Tony        remove dotted line above footer link.
  1.2   28/08/2013  Tony        Use blog url instead of blog name.
  1.2   09/11/2012  Tony        Spell my name correctly
  1.2   28/08/2013  Tony        fix incompatabilities in function/variable naming
  1.2   29/08/2013  Tony		Add nofollow to external links

  2.0   31/08/2013  Tony	Total rewrite using OOP Methodology
  2.1   17/02/2014  Tony        Add ability to update plugin automatically
  2.2   13/03/2014  Tony        Add last updated to comply with new Australian privacy laws
 */

require 'plugin-updates/plugin-update-checker.php';
$MyUpdateChecker = new PluginUpdateChecker(
    'http://lawforwebsites.info/content/uploads/2012/06/info.json',
    __FILE__,
    'lawforwebsites'
);

if (!class_exists('LawForWebsites_WP_Legals')) {

	class LawForWebsites_WP_Legals {
		
		// Construct the plugin object
		public function __construct() {
			// register actions
			add_action('admin_init', array(&$this, 'admin_init'));
			add_action('admin_menu', array(&$this, 'add_menu'));
			add_action('wp_enqueue_scripts', array(&$this, 'lawforwebsites_wp_legals_styles'));
			add_action( 'admin_enqueue_scripts', array(&$this, 'lawforwebsites_wp_legals_styles'));
			add_action('wp_footer', array(&$this, 'lawforwebsites_footer_linkback'));
                        add_shortcode('terms-of-use', array($this, 'law_for_websites_terms'));
                        add_shortcode('privacy-policy', array($this, 'law_for_websites_privacy'));  
                }  // END public function __construct 

		// Activate the plugin
		public static function activate() {
		
			// Do nothing
			
		} //END public static function activate
		
		// Deactivate the plugin
		public static function deactivate() {
		
			delete_option('lfw_legal_jurisdiction');
			delete_option('lfw_linkback');
			delete_option('lfw_autoresponder');
		} // END public static function deactivate
		
		// hook into WP's admin_init action hook
		public function admin_init() {

			// Set up the settings for this plugin
			$this->init_settings();
			// Possibly do additional admin_init tasks
		}

		// Initialize custom settings
		public function init_settings() {

			// register the settings for this plugin
			register_setting('lawforwebsites_wp_legals-group', 'lfw_legal_jurisdiction');
			register_setting('lawforwebsites_wp_legals-group', 'lfw_linkback');
			register_setting('lawforwebsites_wp_legals-group', 'lfw_autoresponder');

		} // END public function init_settings()

		// add a menu
		public function add_menu() {

        	add_menu_page('Law For Websites Settings', 'LFW Settings', 'manage_options', 'lawforwebsites', array(&$this, 'plugin_settings_page'), plugins_url('/auction_hammer_gavel.ico', __FILE__));
		} // END public function add_menu()

		// Menu Callback
		public function plugin_settings_page() {

			if(!current_user_can('manage_options')) {
				wp_die(__('You do not have sufficient permissions to access this page.'));
			}
			
			// Render the settings template
			include(sprintf("%s/templates/settings.php", dirname(__FILE__)));
		} // END public function plugin_settings_page()
		
		// add a linkback to lawforwebsites.info in footer
		public function lawforwebsites_footer_linkback() {
			if (get_option('lfw_linkback') == '1')
				include(sprintf("%s/templates/footerlink.php", dirname(__FILE__)));
		}

		// Register the stylesheet
		public function lawforwebsites_wp_legals_styles() {
			wp_register_style('lawforwebsites_wp_legals_styles', plugins_url('css/lawforwebsites.css', __FILE__));
			wp_enqueue_style('lawforwebsites_wp_legals_styles');
		} //END public function lawforwebsites_wp_legals_styles()
	
		// terms of use shortcode
        public function law_for_websites_terms() {  

			include(sprintf("%s/templates/terms.php", dirname(__FILE__)));
		} // END law_for_websites_terms()
		
		// privacy policy shortcode
        public function law_for_websites_privacy() {  

			include(sprintf("%s/templates/privacy.php", dirname(__FILE__)));
		} // END law_for_websites_privacy()
		
	} // END class LawForWebsites_WP_Legals
	
} // END if(!class_exists())

if(class_exists('LawForWebsites_WP_Legals')) {

	// Installation and uninstallation hooks
	register_activation_hook(__FILE__, array('LawForWebsites_WP_Legals', 'activate'));
	register_deactivation_hook(__FILE__, array('LawForWebsites_WP_Legals', 'deactivate'));

	// instantiate the plugin class
	$lawforwebsites_wp_legals = new LawForWebsites_WP_Legals();
	
	if(isset($lawforwebsites_wp_legals)) {
	
		// Add settings, help and support links to the plugin page 
		function lawforwebsites_register_plugin_links($links, $file) {
			$base = plugin_basename(__FILE__);
			if ($file == $base) {
				$links[] = '<a href="admin.php?page=lawforwebsites">' . __('Settings','lawforwebsites') . '</a>';
				$links[] = '<a rel="nofollow" href="http://lawforwebsites.info/plugin-help/" target="_blank">' . __('HELP','lawforwebsites') . '</a>';
				$links[] = '<a href="Mailto:admin@meoverhere.it">' . __('Support','lawforwebsites') . '</a>';
			} // END lawforwebsites_register_plugin_links()
			return $links;
		}
		
		add_filter( 'plugin_row_meta', 'lawforwebsites_register_plugin_links',10,2);

        // Add the settings link to the plugins page
        function lawforwebsites_settings_link($links) { 
            $settings_link = '<a href="admin.php?page=lawforwebsites">Settings</a>'; 
            array_unshift($links, $settings_link); 
            return $links; 
        } // END lawforwebsites_settings_link()

        $plugin = plugin_basename(__FILE__); 
        add_filter("plugin_action_links_$plugin", 'lawforwebsites_settings_link');
    } // END if(isset($lawforwebsites_wp_legals))
	
} // END if(class_exists())

